@@ -299,10 +299,8 @@ If HEADER-ONLY is non-nil only decode header and return filename."
 		(insert-file-contents-literally file-name)))
 	  (error "Can not binhex")))
       (and work-buffer (kill-buffer work-buffer))
-      (condition-case ()
-	  (if file-name (delete-file file-name))
-	(error))
-      )))
+      (ignore-errors
+	(if file-name (delete-file file-name))))))
 
 (provide 'binhex)
 
